@@ -15,4 +15,4 @@ if __name__ == "__main__":
     })
     query = "please give me revenue for player of October 2020"
     response_df = ask_dataframe(df, query)
-    print(response_df)
+    print(response_df[0])
